"use client";
import React, { useState, useEffect, useRef } from "react";
import axios from "axios";
import { routes } from "@/libs/api";
import Modal from "../../../../components/Boat-listing/Modal";
// import {handleImageUpload} from "@/libs/uploadAsset"
import {
  handleImageUpload,
  handleVideoUpload,
  handleFileUpload,
  handleThumbnailUpload,
} from "@/libs/uploadAsset";
import "react-phone-number-input/style.css";
import PhoneInput from "react-phone-number-input";
import { getExampleNumber } from "libphonenumber-js";
import flags from "react-phone-number-input/flags";
// import { toast } from 'react-toastify';
// import 'react-toastify/dist/ReactToastify.css';
import { toast } from "react-toastify";
import Listing from "@/components/global/Listing";
import Image from "next/image";
import metadata from "libphonenumber-js/metadata.min.json";
import { IoReload } from "react-icons/io5";

// toast.configure();
// interior and exterior colors
const colors = [
  "Black",
  "Blue",
  "Brown",
  "Burgundy",
  "Gold",
  "Grey",
  "Orange",
  "Green",
  "Purple",
  "Red",
  "Silver",
  "Beige",
  "Tan",
  "Teal",
  "White",
  "Yellow",
  "Dark",
  "Light",
  "Pink",
  "DarkKhaki",
  "DarkGreen",
  "DarkBlue",
  "DarkCyan",
  "Aqua",
];
const extrasList = [
  "Steel",
  "Aluminium",
  "Fibre-Reinforced",
  "Plastic",
  "Fibre-reinforced plastic",
  "Plywood",
  "Fibre",
  "Resin",
  "Ferrocement",
  "Gelcoat",
  "Kevlar",
  "Polyvinyl chloride",
  "Aux Audio In",
  "CD Player",
  "Premium Sound System",
  "Premium Lights",
  "DVD Player",
  "Power Seats",
  "Racing Seats",
  "Bluetooth System",
  "Private Pool",
  "Satellite / Cable TV",
  "Business Center",
  "Kids Play Area",
  "Prayer Room",
];

const getMaxLengthForCountry = (country) => {
  const exampleNumber = getExampleNumber(country, metadata);
  return exampleNumber
    ? exampleNumber.formatNational().replace(/\D/g, "").length
    : Infinity;
};

function Page() {
  // image and video
  const [images, setImages] = useState([]);
  const [video, setVideo] = useState(null);
  const [thumbnail, setThumbnail] = useState(null);
  const [errors, setErrors] = useState({});
  const [maxLength, setMaxLength] = useState(Infinity);
  const [selectedCountryPhone, setSelectedCountryPhone] = useState("US");
  const [phoneNumber, setPhoneNumber] = useState("");
  const [loading, setLoading] = useState(false);

  const fileInputRef = useRef(null);

  const handleImageChange = (e) => {
    const files = Array.from(e.target.files);
    const validFiles = [];

    const checkFile = (file) => {
      return new Promise((resolve) => {
        const reader = new FileReader();
        reader.onload = (event) => {
          const img = new window.Image();
          img.onload = () => {
            resolve(file);
          };
          img.onerror = () => {
            toast.error(
              `The file ${file.name} could not be loaded as an image`
            );
            resolve(null);
          };
          img.src = event.target.result;
        };
        reader.onerror = () => {
          alert(`The file ${file.name} could not be read`);
          resolve(null);
        };
        reader.readAsDataURL(file);
      });
    };

    const processFiles = async () => {
      for (const file of files) {
        if (file.size > 2 * 1024 * 1024) {
          toast.error(`The file ${file.name} exceeds the 2MB size limit`);
        } else {
          const validFile = await checkFile(file);
          if (validFile) {
            validFiles.push(validFile);
          }
        }
      }
      if (images.length + validFiles.length > 7) {
        toast.error("You can only upload a maximum of 7 images");
        return;
      }
      setImages((prevImages) => [...prevImages, ...validFiles]);
    };

    processFiles();
  };

  const handleImageRemove = (index) => {
    setImages((prevImages) => prevImages.filter((_, i) => i !== index));
    setFormData((prevFormData) => ({
      ...prevFormData,
      pictures: prevFormData.pictures.filter((_, i) => i !== index),
    }));
  };

  const handleVideoChange = (e) => {
    const file = e.target.files[0];
    if (file.size > 50 * 1024 * 1024) {
      toast.error("Maximum file size for videos is 50MB");
      fileInputRef.current.value = null;
      return;
    }

    const video = document.createElement("video");
    video.preload = "metadata";

    video.onloadedmetadata = () => {
      window.URL.revokeObjectURL(video.src);
      setVideo(file);
      fileInputRef.current.value = null;
    };

    video.src = URL.createObjectURL(file);
  };

  const handleVideoRemove = () => {
    setVideo(null);
  };

  const handleCountryChange = (value) => {
    setSelectedCountryPhone(value);

    const newMaxLength = getMaxLengthForCountry(value);
    setMaxLength(newMaxLength);
  };

  const handleThumbImageChange = (event) => {
    const selectedFile = event.target.files[0];
    if (selectedFile) {
      const reader = new FileReader();
      reader.onload = (e) => {
        const img = new window.Image();
        img.onload = () => {
          setThumbnail(selectedFile);
        };
        img.onerror = () => {
          toast.error(
            `The file ${selectedFile.name} could not be loaded as an image`
          );
        };
        img.src = e.target.result;
      };
      reader.onerror = () => {
        toast.error(`The file ${selectedFile.name} could not be read`);
      };
      reader.readAsDataURL(selectedFile);
    }
  };

  const handleThumbImageRemove = () => {
    setThumbnail(null);
    setFormData((prevFormData) => ({
      ...prevFormData,
      thumbnailImg: null,
    }));
  };
  // for file
  const [file, setFile] = useState(null);

  const handleFileChange = (event) => {
    setFile(event.target.files[0]);
  };

  const handleFileRemove = () => {
    setFile(null);
  };

  const truncateFileName = (fileName) => {
    return fileName.length > 30 ? `${fileName.substring(0, 30)}...` : fileName;
  };

  const validateForm = (data) => {
    const errors = {};

    if (images.length === 0) errors.pictures = "Pictures are Required";
    if (!file)
      errors.evaluationCertificate = "Evaluation Certificate is Required";
    if (!thumbnail) errors.thumbnail = "Thumbnail are Required";
    if (!data.assetType.trim()) errors.assetType = "Asset type is required";
    if (!data.country.trim()) errors.country = "Country is required";
    if (!data.city.trim()) errors.city = "City is required";
    if (!data.neighbourhood.trim())
      errors.neighbourhood = "Neighbourhood is required";
    if (!data.category.trim()) errors.category = "Category is required";
    if (!data.model.trim()) errors.model = "Model is required";
    if (!data.title.trim()) {
      errors.title = "Title is required";
    } else if (data.title.length > 50) {
      errors.title = "Title must be less than 50 characters";
    }
    if (!data.phoneNumber.trim()) {
      errors.phoneNumber = "Phone number is required";
    } else if (!isValidPhoneNumber(data.phoneNumber)) {
      errors.phoneNumber = "Phone number is invalid";
    }
    if (!data.condition.trim()) errors.condition = "Condition is required";
    if (!data.price.trim()) errors.price = "Rrice is required";
    if (!data.weight.trim()) errors.weight = "Weight is required";
    if (!data.sellerType.trim()) errors.sellerType = "Seller Type is required";
    if (!data.description.trim())
      errors.description = "Description is required";
    if (!data.length.trim()) errors.length = "Length is required";
    // if (!data.brands.trim()) errors.brands = "Brands is required";
    if (!data.age.trim()) errors.age = "Age is required";
    if (!data.usage.trim()) errors.usage = "Usage is required";
    // if (!data.locateBoat.trim()) errors.locateBoat = "locateBoat is required";
    if (!data.sportsOutdoorPrice.trim())
      if (!data.warrenty.trim())
        // errors.sportsOutdoorPrice = "sportsOutdoorPrice is required";
        errors.warrenty = "Warrenty is required";
    if (!data.seats.trim()) errors.seats = "Seats is required";
    // if (!data.pictures.trim()) errors.pictures = "pictures is required";
    // if (!data.video.trim()) errors.video = "video side is required";
    // if (!data.thumbnailImg.trim()) errors.thumbnailImg = " thumbnailImg type is required";
    // if (!safeTrim(data.evaluationCertificate))
    //   errors.evaluationCertificate = "Evaluation Certificate is required";
    if (!data.evaludationComponents.trim())
      errors.evaludationComponents = "Evaludation Components are required";
    // if (!data.sportsOutdoorPrice.trim())
    //   errors.sportsOutdoorPrice = "sportsOutdoorPrice is required";
    if (!data.category.trim()) errors.category = "Category is required";
    if (!data.model.trim()) errors.model = "Model is required";
    return errors;
  };

  const isValidPhoneNumber = (phoneNumber) => {
    return phoneNumber && phoneNumber.length >= 10;
  };

  const validateField = (name, value) => {
    let error = "";

    switch (name) {
      case "title":
        if (!value) {
          error = "Title is required.";
        } else if (value.length > 50) {
          error = "Title cannot exceed 50 characters.";
        }
        break;
      case "phoneNumber":
        if (!value.trim()) {
          error = "Phone number is required";
        } else if (!isValidPhoneNumber(value)) {
          error = "Phone number is invalid";
        }
        break;
      case "condition":
        if (!value.trim()) {
          error = "condition is required";
        }
        break;
      case "price":
        if (!value.trim()) {
          error = "price is required";
        }
        break;
      case "weight":
        if (!value.trim()) {
          error = "weight is required";
        }
        break;
      case "sellerType":
        if (!value.trim()) {
          error = "sellerType is required";
        }
        break;
      case "description":
        if (!value.trim()) {
          error = " description is required";
        }
        break;
      case "length":
        if (!value.trim()) {
          error = " length is required";
        }
        break;
      case "brands":
        if (!value.trim()) {
          error = "  brands is required";
        }
        break;
      case "age":
        if (!value.trim()) {
          error = "   age is required";
        }
        break;
      case "usage":
        if (!value.trim()) {
          error = "   usage is required";
        }
        break;
      case "locateBoat":
        if (!value.trim()) {
          error = "   locateBoat is required";
        }
        break;
      case "sportsOutdoorPrice":
        if (!value.trim()) {
          error = "   sportsOutdoorPrice is required";
        }
        break;
      case "warrenty":
        if (!value.trim()) {
          error = "   warrenty is required";
        }
        break;
      case " seats":
        if (!value.trim()) {
          error = "    seats is required";
        }
        break;

      // Add more cases for other fields if needed
      default:
        break;
    }

    setErrors((prevErrors) => ({ ...prevErrors, [name]: error }));
  };

  const handleBlur = (e) => {
    const { name, value } = e.target;
    validateField(name, value);
  };

  // submit
  const handleSubmit = async (e) => {
    e.preventDefault();
    setLoading(true);

    try {
      // Pre-validate the form data
      const validationErrors = validateForm(formData);
      if (Object.keys(validationErrors).length > 0) {
        setErrors(validationErrors);
        setLoading(false);
        handleScroll();
        return;
      }

      // Run uploads in parallel
      const [imageID, videoID, fileID, thumbnailID] = await Promise.all([
        handleImageUpload(images),
        handleVideoUpload(video),
        handleFileUpload(file),
        handleThumbnailUpload(thumbnail),
      ]);

      const updatedFormData = {
        ...formData,
        pictures: imageID,
        video: videoID,
        evaluationCertificate: fileID,
        thumbnailImg: thumbnailID,
      };

      // Submit form data to the backend
      try {
        const response = await axios.post(routes.boatListing, updatedFormData);
        if (response.data) {
          // Show success toast notification
          toast.success("Form submitted successfully!");
          setModalOpen(true); 
          // Clear form data and reset state
          resetFormState();
        }
      } catch (error) {
        console.error("Error submitting form:", error);
        // Show error toast notification
        toast.error("Error submitting form. Please try again.");
      }
    } catch (error) {
      console.error("Error uploading files:", error);
      // Handle error (e.g., show error message)
      toast.error("Error uploading files. Please try again.");
    } finally {
      setLoading(false);
    }
  };

  // Function to reset form state
  const resetFormState = () => {
    setFormData({
      assetType: "select Asset Type",
      country: "",
      city: "",
      neighbourhood: "",
      title: "",
      phoneNumber: "",
      condition: "",
      price: "",
      weight: "",
      sellerType: "",
      description: "",
      length: "",
      brands: "",
      age: "",
      usage: "",
      locateBoat: "",
      sportsOutdoorPrice: "",
      warranty: "",
      seats: "",
      pictures: "",
      video: null,
      thumbnailImg: "",
      evaluationCertificate: "",
      evaluationComponents: "",
      exteriorColor: "",
      interiorColor: "",
      extras: "",
      category: "",
      model: "",
    });
    setFile(null);
    setThumbnail(null);
    setImages(null);
    setVideo(null);
    setValue("");
    setSelectedCountry(null);
    setSelectedCity(null);
    setSelectedCategory("Select Category");
    setSelectedModel("Select Model");
  };

  // phone num valid
  const [value, setValue] = useState();

  if (isValidPhoneNumber(setValue.toString()) === false) {
    // console.log("Hello this is a Unvalid phone number");
  }

  if (isValidPhoneNumber(setValue.toString()) === true) {
    // console.log("Hello this is a valid phone number");
  }

  const handlePhoneNumberChange = (value) => {
    const cleanedValue = value?.replace(/\D/g, "");
    if (cleanedValue?.length <= maxLength) {
      setFormData({ ...formData, phoneNumber: value });
      setErrors({ ...errors, phoneNumber: "" });
      setPhoneNumber(value);
    }
  };

  const [selectedExteriorColors, setSelectedExteriorColors] = useState([]);
  const [otherExteriorColor, setOtherExteriorColor] = useState("");
  const [selectedInteriorColors, setSelectedInteriorColors] = useState([]);
  const [otherInteriorColor, setOtherInteriorColor] = useState("");

  const handleExteriorCheckboxChange = (event) => {
    const { value, checked } = event.target;
    let updatedColors;

    if (checked) {
      updatedColors = [...selectedExteriorColors, value];
    } else {
      updatedColors = selectedExteriorColors.filter((color) => color !== value);
    }

    setSelectedExteriorColors(updatedColors);
  };

  const handleOtherExteriorColorChange = (event) => {
    setOtherExteriorColor(event.target.value);
  };

  const handleInteriorCheckboxChange = (event) => {
    const { value, checked } = event.target;
    let updatedColors;

    if (checked) {
      updatedColors = [...selectedInteriorColors, value];
    } else {
      updatedColors = selectedInteriorColors.filter((color) => color !== value);
    }

    setSelectedInteriorColors(updatedColors);
  };

  const handleOtherInteriorColorChange = (event) => {
    setOtherInteriorColor(event.target.value);
  };

  useEffect(() => {
    const allSelectedExteriorColors = otherExteriorColor
      ? [...selectedExteriorColors, otherExteriorColor]
      : selectedExteriorColors;

    setFormData((prev) => ({
      ...prev,
      exteriorColor: allSelectedExteriorColors,
    }));
  }, [selectedExteriorColors, otherExteriorColor]);

  useEffect(() => {
    const allSelectedInteriorColors = otherInteriorColor
      ? [...selectedInteriorColors, otherInteriorColor]
      : selectedInteriorColors;

    setFormData((prev) => ({
      ...prev,
      interiorColor: allSelectedInteriorColors,
    }));
  }, [selectedInteriorColors, otherInteriorColor]);

  // extra
  const [selectedExtras, setSelectedExtras] = useState([]);

  const handleCheckboxChange = (event) => {
    const { value, checked } = event.target;
    let updatedExtras;

    if (checked) {
      updatedExtras = [...selectedExtras, value];
    } else {
      updatedExtras = selectedExtras.filter((extra) => extra !== value);
    }

    setSelectedExtras(updatedExtras);
  };

  useEffect(() => {
    setFormData((prev) => ({
      ...prev,
      extras: selectedExtras,
    }));
  }, [selectedExtras]);

  // category dropdown
  const [dropdownVisible, setDropdownVisible] = useState(false);
  const [modelDropdownVisible, setModelDropdownVisible] = useState(false);
  const [selectedCategory, setSelectedCategory] = useState("Any");
  const [selectedModel, setSelectedModel] = useState("All");
  const [models, setModels] = useState(["1", "2", "3", "4"]);

  // const [value, setValue] = useState('');
  const categories = {
    Motorboats: [
      "Cabin Cruiser Boat",
      "Cruiser Boat",
      "Fishing Boat",
      "Outboard Dayboat",
      "Ponton/House Boat",
      "Racing Boat",
      "Sleeper/Mini Yacht",
      "Wakeboarding/Ski Boat",
      "Yacht",
      "Other",
    ],
    "Row/Paddle Boats": ["Canoe/Row Boat", "Paddle Boat", "Other"],
    Sailboats: [
      "Catamaran",
      "Cruiser/Day Sailor",
      "DhowVoilier",
      "Dinghy",
      "Racer",
      "Sailing Yacht",
      "Other",
    ],
  };

  const toggleDropdown = () => {
    setDropdownVisible(!dropdownVisible);
  };

  const toggleModelDropdown = () => {
    setModelDropdownVisible(!modelDropdownVisible);
  };

  const handleCategoryClick = (category) => {
    setSelectedCategory(category);
    setModels(categories[category]);
    setDropdownVisible(false);
    setSelectedModel("All"); // Reset model selection when category changes
    setFormData((prevFormData) => ({
      ...prevFormData,
      category: category,
      model: "",
    }));
  };

  const handleModelClick = (model) => {
    setSelectedModel(model);
    setModelDropdownVisible(false);
    setFormData((prevFormData) => ({
      ...prevFormData,
      model: model,
    }));
  };
  const [isOpen, setIsOpen] = useState(false);
  const [countries, setCountries] = useState([]);
  const [selectedCountry, setSelectedCountry] = useState("Select Country");
  const [cities, setCities] = useState([]);
  const [isCityDropdownOpen, setIsCityDropdownOpen] = useState(false);
  const [isNeighbourDropdownOpen, setIsNeighbourDropdownOpen] = useState(false);
  const [neighbourhood, setneighbourhood] = useState("Select Neighbourhood");
  const [selectedCity, setSelectedCity] = useState("Select a City");
  const [searchQuery, setSearchQuery] = useState("");
  const [neighbourhoods, setNeighbourhoods] = useState([]);
  const [selectedNeighbourhood, setSelectedNeighbourhood] = useState(
    "Select Neighbourhood"
  );

  // Fetch all countries
  useEffect(() => {
    const fetchCountries = async () => {
      try {
        const response = await fetch("/api/countries");
        const data = await response.json();
        setCountries(data);
        console.log(data, "sss");
      } catch (error) {
        console.error("Error fetching countries data:", error);
      }
    };
    fetchCountries();
  }, []);

  const fetchCities = async (countryName) => {
    try {
      const response = await axios.get(
        `/api/country?name=${countryName.replace(/ /g, "+")}`
      );
      setCities(response.data.cities);
      console.log(response.data.cities, "ssssssd");
    } catch (error) {
      console.error("Error fetching cities data:", error);
    }
  };
  const fetchNeighbourhoods = async (cityName) => {
    try {
      const res = await axios.get(
        `/api/city-coordinates?name=${cityName.replace(/ /g, "+")}`
      );
      const { lat, lng } = res.data.location;
      const response = await axios.get(
        `/api/neighbourhoods?lat=${lat}&lng=${lng}&city=${cityName.replace(
          / /g,
          "+"
        )}`
      );
      setNeighbourhoods(response.data.neighbourhoods);
    } catch (error) {
      console.error("Error fetching cities data:", error);
    }
  };

  const toggleDropdownn = () => {
    setIsOpen(!isOpen);
  };

  const handleCountrySelect = (country) => {
    setSelectedCountry(country.country);
    setIsOpen(false);
    fetchCities(country.country); // Add this line to fetch cities when a country is selected
    setFormData((prevFormData) => ({
      ...prevFormData,
      country: selectedCountry,
    }));
  };

  const toggleCityDropdown = () => {
    setIsCityDropdownOpen(!isCityDropdownOpen);
  };

  const toggleNeighbourDropdown = () => {
    setIsNeighbourDropdownOpen(!isNeighbourDropdownOpen);
  };

  const handleNeighbour = (city) => {
    console.log(city, "city");
    setFormData((prevFormData) => ({
      ...prevFormData,
      neighbourhood: selectedNeighbourhood,
    }));
    setSelectedNeighbourhood(city);
    setNeighbourhoods(city);
    setIsNeighbourDropdownOpen(false);
  };

  const handleCitySelect = (city) => {
    setSelectedCity(city);
    fetchNeighbourhoods(city);
    setFormData((prevFormData) => ({
      ...prevFormData,
      city: city,
    }));
    setIsCityDropdownOpen(false);
  };

  // Filter countries based on search query
  const filteredCountries = countries.filter((country) =>
    country.country.toLowerCase().includes(searchQuery.toLowerCase())
  );

  const initialFormData = {
    assetType: "Boats For Sale",
    country: "",
    city: "",
    neighbourhood: "",
    title: "",
    phoneNumber: "",
    condition: "",
    price: "",
    weight: "",
    sellerType: "",
    description: "",
    length: "",
    brands: "",
    age: "",
    usage: "",
    locateBoat: "",
    sportsOutdoorPrice: "",
    warrenty: "",
    seats: "",
    pictures: "",
    video: null,
    thumbnailImg: "",
    evaluationCertificate: "",
    evaludationComponents: "",
    sportsOutdoorPrice: "",
    exteriorColor: [],
    interiorColor: [],
    extras: [],
    category: "",
    model: "",
  };

  const [formData, setFormData] = useState(initialFormData);

  // all dropdowns
  const [dropdowns, setDropdowns] = useState({
    country: false,
    warrenty: false,
    condition: false,
    sellerType: false,
    length: false,
    age: false,
    usage: false,
    evaludationComponents: "",
    assetType: "",
  });
  const conditionOptions = ["Flawless", "Excellent", "Average", "Poor"];
  const age = [
    "Brand New",
    "0-1 months",
    "1-6 months",
    "6-12 months",
    "1-2 years",
    "2-5 years",
    "5-10 years",
    "10+ years",
  ];

  const usage = [
    "Still with the dealer",
    "Only used once since it was purchased new",
    "Used only a few times since it was purchased new",
    "Used only or twicw a month since purchased",
    "Used numerous times per week since purchased",
  ];
  const seller = ["Owner", "Dealer", "Dealership/Certified Pre-Owned"];
  const warrenty = ["Yes", "No", "Does not apply"];

  const length = [
    "Under 10 ft.",
    "10-14 ft.",
    "15-19 ft.",
    "20-24 ft.",
    "25-29 ft.",
    "30-39 ft.",
    "40-49 ft.",
    "50-69 ft.",
    "70-100 ft.",
    "100+ ft.",
  ];

  const companies = ["Bilal Evaluation companies"];

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({ ...formData, [name]: value });
  };

  const handleToggleDropdown = (dropdownName) => {
    setDropdowns((prevState) => ({
      ...prevState,
      [dropdownName]: !prevState[dropdownName],
    }));
  };

  const handleSelectOption = (dropdownName, option) => {
    setFormData({ ...formData, [dropdownName]: option });
    setDropdowns({ ...dropdowns, [dropdownName]: false });
  };
  const handleScroll = () => {
    window.scrollTo({ top: 0, behavior: "smooth" });
  };
  const [isModalOpen, setModalOpen] = useState(false);

  const handleInputClick = () => {
    setModalOpen(true);
  };

  const handleCloseModal = () => {
    setModalOpen(false);
  };

  const [description, setDescription] = useState("");

  const handleDescriptionChange = (event) => {
    setDescription(event.target.value);
  };

  return (
    // <Modal show={showModal} onClose={handleCloseModal} />
    <div>
      <section>
        <h2 className="text-dark-grey text-center xl:text-[40px] lg:text-4xl md:text-3xl sm:text-2xl xxs:text-xl font-medium leading-normal pt-[60px]">
          Final Steps to Listing Your Asset
        </h2>

        <div className="mt-[50px]">
          <Listing
            formData={formData}
            dropdowns={dropdowns}
            toggleCityDropdown={toggleCityDropdown}
            toggleDropdownn={toggleDropdownn}
            toggleModelDropdown={toggleModelDropdown}
            toggleNeighbourDropdown={toggleNeighbourDropdown}
            handleToggleDropdown={handleToggleDropdown}
            isOpen={isOpen}
            isCityDropdownOpen={isCityDropdownOpen}
            isNeighbourDropdownOpen={isNeighbourDropdownOpen}
            toggleDropdown={toggleDropdown}
            neighbourhoods={neighbourhoods}
            selectedCategory={selectedCategory}
            dropdownVisible={dropdownVisible}
            cities={cities}
            selectedModel={selectedModel}
            selectedNeighbourhood={selectedNeighbourhood}
            modelDropdownVisible={modelDropdownVisible}
            searchQuery={searchQuery}
            setSearchQuery={setSearchQuery}
            filteredCountries={filteredCountries}
            categories={categories}
            models={models}
            handleCitySelect={handleCitySelect}
            handleCategoryClick={handleCategoryClick}
            handleModelClick={handleModelClick}
            handleNeighbour={handleNeighbour}
            handleCountrySelect={handleCountrySelect}
            handleSelectOption={handleSelectOption}
            selectedCity={selectedCity}
            selectedCountry={selectedCountry}
            boat={true}
            neighbourhood={neighbourhood}
          />
          {/* end  */}
          <main className="max-w-[1300px] mx-auto lg:px-[35px] md:px-10 xxs:px-5 shadow-neons bg-whitee rounded-[5px]">
            {/* input one  */}
            <form className="pt-[50px]">
              <div className="grid gap-6 md:grid-cols-2 xxs:grid-cols-1">
                <div className="relative flex flex-col justify-start">
                  <input
                    type="text"
                    maxLength={50}
                    className={`w-full shadow-neons h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal ${
                      errors.title
                        ? "border-red-500 border outline-none focus:outline-none"
                        : ""
                    }`}
                    required
                    placeholder="Title your Boat (max. 50 characters)"
                    name="title"
                    value={formData.title}
                    onChange={handleChange}
                    onBlur={handleBlur}
                  />

                  {errors.title && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px] ">
                      **{errors.title}
                    </span>
                  )}
                </div>

                {/* 2  phone number*/}
                <div className="relative w-full">
                  <div className="custom-container-dev">
                    <PhoneInput
                      flags={flags}
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal outline-none ${
                        errors.phoneNumber
                          ? "border-red-500 border outline-none focus:outline-none"
                          : ""
                      }`}
                      placeholder="Enter phone number"
                      value={phoneNumber}
                      onChange={handlePhoneNumberChange}
                      onCountryChange={handleCountryChange}
                      defaultCountry="US"
                      country={selectedCountryPhone}
                      limitMaxLength={maxLength}
                      international
                      countryCallingCodeEditable={false}
                    />
                    <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer">
                      <Image
                        width={12}
                        height={12}
                        src="/listing/tick.svg"
                        alt="tick"
                      />
                    </div>
                    {errors.phoneNumber && (
                      <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                        **{errors.phoneNumber}
                      </span>
                    )}
                  </div>
                </div>

                {/* 3 picture  */}
                <div
                  className={`${
                    errors.pictures ? "border-red-500 border" : "shadow-neons"
                  } h-[191px] relative px-[20px] pt-[13px]`}
                >
                  <h2 className="text-dark-grey text-[15px] font-normal leading-[26px]">
                    Accepted formats:
                  </h2>
                  <p className="text-dark-grey text-[10px] font-normal leading-[177%]">
                    JPG, PNG, GIF. Maximum file size: 2MB
                  </p>

                  <div className="flex flex-wrap mt-4 w-[60%]">
                    {images?.map((image, index) => (
                      <div key={index} className="w-1/5 p-2 relative group">
                        <Image
                          width={20}
                          height={20}
                          src={URL.createObjectURL(image)}
                          alt={`upload-${index}`}
                          className="w-full h-auto"
                        />

                        <button
                          onClick={() => handleImageRemove(index)}
                          className="absolute top-0 right-0 w-6 flex justify-center items-center h-6 p-1 bg-red-500 text-white rounded-full opacity-0 group-hover:opacity-100 transition-opacity"
                          title="Remove image"
                        >
                          &times;
                        </button>
                      </div>
                    ))}
                  </div>

                  <input
                    type="file"
                    id="boat-image"
                    className="hidden"
                    accept="image/*"
                    multiple
                    required
                    onChange={handleImageChange}
                  />

                  <div className="absolute right-[20px] xl:top-0 xxs:top-[55px]">
                    <label
                      htmlFor="boat-image"
                      className="flex flex-col items-center justify-center w-[176px] 
            xl:h-[154px] xxs:h-[110px] 
            shadow-neonsm cursor-pointer my-[19px]"
                    >
                      <Image
                        width={45}
                        height={45}
                        src="/listing/camera.svg"
                        alt="Upload Image"
                      />

                      <span className="text-[17px] text-dark-grey font-normal pt-[18px]">
                        Add Pictures
                      </span>
                    </label>
                  </div>
                  {errors.pictures && (
                    <span className="text-red-500 text-sm -ml-4 font-medium absolute top-[99%]">
                      **{errors.pictures}
                    </span>
                  )}
                </div>

                {/* thumbnail */}
                <div
                  className={`${
                    errors.thumbnail ? "border-red-500 border" : "shadow-neons"
                  } h-[191px] relative px-[20px] pt-[13px]`}
                >
                  <h2 className="text-dark-grey text-[15px] font-normal leading-[26px]">
                    Accepted formats :
                  </h2>
                  <p className="text-dark-grey text-[10px] font-normal leading-[177%]">
                    JPG, PNG, GIF. Maximum file size: 2MB
                  </p>

                  <div className="flex flex-wrap mt-2 w-[80%]">
                    {thumbnail && (
                      <div className="w-2/5 p-2 relative group">
                        <Image
                          width={20}
                          height={20}
                          src={URL.createObjectURL(thumbnail)}
                          alt="uploaded-image"
                          className="w-full h-auto"
                        />
                        <button
                          onClick={handleThumbImageRemove}
                          className="absolute top-0 right-0 w-6 flex justify-center items-center h-6 p-1 bg-red-500 text-white rounded-full opacity-0 group-hover:opacity-100 transition-opacity"
                          title="Remove image"
                        >
                          &times;
                        </button>
                      </div>
                    )}
                  </div>

                  <input
                    type="file"
                    id="car-image"
                    className="hidden"
                    accept="image/*"
                    required
                    onChange={handleThumbImageChange}
                  />

                  <div className="absolute right-[20px] xl:top-0 xxs:top-[55px]">
                    <label
                      htmlFor="car-image"
                      className="flex flex-col items-center justify-center w-[176px] xl:h-[154px] xxs:h-[110px] shadow-neonsm cursor-pointer my-[19px]"
                    >
                      <Image
                        width={45}
                        height={45}
                        src="/listing/camera.svg"
                        alt="Upload thumbnail"
                      />
                      <span className="text-[17px] text-dark-grey font-normal pt-[18px]">
                        Add thumbnail
                      </span>
                    </label>
                  </div>
                  {errors.thumbnail && (
                    <span className="text-red-500 text-sm -ml-4 font-medium absolute top-[99%]">
                      **{errors.thumbnail}
                    </span>
                  )}
                </div>

                {/* 4 video*/}
                <div className="shadow-neons h-[190px] relative px-[20px] pt-[13px]">
                  <h2 className="text-dark-grey text-[15px] font-normal leading-[26px]">
                    Accepted formats:
                  </h2>
                  <p className="text-dark-grey text-[10px] font-normal leading-[177%]">
                    MP4, MOV. Maximum file size: 50MB
                  </p>

                  {video && (
                    <div className="relative mt-2 h-28 w-28">
                      <video
                        width="100%"
                        controls
                        src={URL.createObjectURL(video)}
                        className="w-full h-auto"
                      />
                      <button
                        onClick={handleVideoRemove}
                        className="absolute h-5 w-5 flex justify-center items-center -top-2 -right-1 p-1 bg-red-500 text-white rounded-full"
                        title="Remove video"
                      >
                        &times;
                      </button>
                    </div>
                  )}

                  <input
                    type="file"
                    id="video-upload"
                    className="hidden"
                    accept="video/*"
                    ref={fileInputRef}
                    onChange={handleVideoChange}
                  />

                  <div className="absolute right-[20px] xl:top-0 xxs:top-[55px]">
                    <label
                      htmlFor="video-upload"
                      className="flex flex-col items-center justify-center w-[176px] xl:h-[144px] xxs:h-[110px]  shadow-neonsm cursor-pointer my-[19px]"
                    >
                      <Image
                        width={40}
                        height={40}
                        src="/listing/video.svg"
                        alt="Upload Video"
                      />
                      <span className="text-[17px] text-dark-grey font-normal pt-[17px]">
                        Add Video
                      </span>
                    </label>
                  </div>
                </div>

                {/* condition and */}
                <div className="relative dropdown-container">
                  <div className="custom-container-dev">
                    <input
                      type="text"
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                        errors.condition && !formData.condition
                          ? "input-field-error "
                          : ""
                      }`}
                      placeholder="Condition"
                      name="condition"
                      value={formData.condition}
                      readOnly // Ensure input is read-only
                      onClick={() => handleToggleDropdown("condition")}
                    />
                  </div>
                  {errors.condition && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.condition}
                    </span>
                  )}

                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                      onClick={() => handleToggleDropdown("condition")}
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                      onClick={() => handleToggleDropdown("condition")}
                    />
                  </div>
                  {dropdowns.condition && (
                    <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      {conditionOptions.map((option, index) => (
                        <div
                          key={index}
                          className="dropdown-option"
                          onClick={() =>
                            handleSelectOption("condition", option)
                          }
                        >
                          {option}
                        </div>
                      ))}
                    </div>
                  )}

                  <div className="relative dropdown-container mt-5">
                    <div className="custom-container-dev">
                      <input
                        type="text"
                        name="price"
                        value={formData.price}
                        onChange={handleChange}
                        className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey placeholder:text-[15px] placeholder:font-normal card-number-input ${
                          errors.price
                            ? "border-red-500 border outline-none focus:outline-none"
                            : ""
                        }`}
                        placeholder="Price"
                        pattern="^4[0-9]{12}(?:[0-9]{3})?$"
                        required
                      />
                    </div>
                    {errors.price && (
                      <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                        **{errors.price}
                      </span>
                    )}
                    <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      <Image
                        width={12}
                        height={12}
                        src="/listing/Vector.svg"
                        alt="Dropdown"
                        className="toggle-icon"
                      />
                      <Image
                        width={12}
                        height={12}
                        src="/listing/vector1.svg"
                        alt="Dropdown"
                        className="toggle-icon rotate-180"
                      />
                    </div>
                  </div>
                  {/* evaulation company */}
                  <div className="relative dropdown-container mt-5">
                    <div className="custom-container-dev">
                      <input
                        type="text"
                        className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                          errors.evaludationComponents &&
                          !formData.evaludationComponents
                            ? "input-field-error "
                            : ""
                        }`}
                        placeholder="Evaluation Companies"
                        name=" evaludationComponents"
                        value={formData.evaludationComponents}
                        readOnly // Ensure input is read-only
                        onClick={() =>
                          handleToggleDropdown("evaludationComponents")
                        }
                      />
                    </div>
                    {errors.evaludationComponents && (
                      <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                        **{errors.evaludationComponents}
                      </span>
                    )}
                    <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      <Image
                        width={12}
                        height={12}
                        src="/listing/Vector.svg"
                        alt="Dropdown"
                        className="toggle-icon"
                        onClick={() =>
                          handleToggleDropdown(" evaludationComponents")
                        }
                      />
                      <Image
                        width={12}
                        height={12}
                        src="/listing/vector1.svg"
                        alt="Dropdown"
                        className="toggle-icon rotate-180"
                        onClick={() =>
                          handleToggleDropdown("evaludationComponents")
                        }
                      />
                    </div>
                    {dropdowns?.evaludationComponents && (
                      <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                        {companies.map((option, index) => (
                          <div
                            key={index}
                            className="dropdown-option"
                            onClick={() =>
                              handleSelectOption(
                                "evaludationComponents",
                                option
                              )
                            }
                          >
                            {option}
                          </div>
                        ))}
                      </div>
                    )}
                  </div>
                </div>
                {/* 6  */}

                {/* 7 certificte and seller type*/}

                <div className="relative w-full dropdown-container">
                  <div className="custom-container-dev">
                    <div>
                      <input
                        type="text"
                        readOnly
                        className={`shadow-neons w-full h-[50px] pl-5 pr-14 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                          errors.evaluationCertificate
                            ? "border-red-500 border outline-none focus:outline-none"
                            : ""
                        }`}
                        placeholder="Request Evaluation Certificate"
                        pattern="^4[0-9]{12}(?:[0-9]{3})?$"
                        required
                      />

                      <Modal show={isModalOpen} onClose={handleCloseModal} />
                    </div>
                  </div>
                  {errors.evaluationCertificate && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.evaluationCertificate}
                    </span>
                  )}
                  <div className="absolute inset-y-0 left-[260px] flex items-center pr-4">
                    <label
                      htmlFor="file-upload"
                      className="cursor-pointer grid grid-cols-2 place-content-between"
                    >
                      <Image
                        width={20}
                        height={20}
                        src="/listing/lastarrow.svg"
                        alt="Upload Icon"
                        className="-mt-20"
                      />
                    </label>
                    <input
                      type="file"
                      id="file-upload"
                      className="hidden"
                      accept="application/pdf"
                      onChange={handleFileChange}
                    />
                  </div>
                  {file === null ? (
                    <Image
                      width={23}
                      height={23}
                      src="/listing/infoicon.svg"
                      alt="infoicon"
                      onClick={handleInputClick}
                      className="absolute right-[15px] top-[15px]"
                    />
                  ) : (
                    <div className="absolute right-[15px] top-[15px] text-dark-grey">
                      {truncateFileName(file.name)}
                    </div>
                  )}
                  {/* </div> */}

                  {/* </div>  seller type*/}
                  <div className="relative dropdown-container mt-5">
                    <div className="custom-container-dev">
                      <input
                        type="text"
                        className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                          errors.sellerType && !formData.sellerType
                            ? "input-field-error "
                            : ""
                        }`}
                        placeholder="Seller Type"
                        name="sellerType"
                        value={formData.sellerType}
                        readOnly // Ensure input is read-only
                        onClick={() => handleToggleDropdown("sellerType")}
                      />
                    </div>
                    {errors.sellerType && (
                      <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                        **{errors.sellerType}
                      </span>
                    )}
                    <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      <Image
                        width={12}
                        height={12}
                        src="/listing/Vector.svg"
                        alt="Dropdown"
                        className="toggle-icon"
                        onClick={() => handleToggleDropdown(" sellerType")}
                      />
                      <Image
                        width={12}
                        height={12}
                        src="/listing/vector1.svg"
                        alt="Dropdown"
                        className="toggle-icon rotate-180"
                        onClick={() => handleToggleDropdown("sellerType")}
                      />
                    </div>
                    {dropdowns.sellerType && (
                      <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                        {seller.map((option, index) => (
                          <div
                            key={index}
                            className="dropdown-option"
                            onClick={() =>
                              handleSelectOption("sellerType", option)
                            }
                          >
                            {option}
                          </div>
                        ))}
                      </div>
                    )}
                    <div className="relative dropdown-container mt-5">
                      <div className="custom-container-dev">
                        <input
                          type="text"
                          className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                            errors.weight
                              ? "border-red-500 border outline-none focus:outline-none"
                              : ""
                          }`}
                          placeholder="Weight"
                          name="weight"
                          onChange={handleChange}
                          value={formData.weight}

                          // onClick={() => handleToggleDropdown('length')}
                        />
                      </div>
                      {errors.weight && (
                        <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                          **{errors.weight}
                        </span>
                      )}
                    </div>
                  </div>
                </div>

                {/* 10  textarea and*/}
                <div className="w-full">
                  <div className="relative dropdown-container">
                    <div className="custom-container-dev">
                      <textarea
                        className={`shadow-neons w-full h-[190px] p-2 pl-5 placeholder:text-dark-grey placeholder:text-[15px] placeholder:font-normal ${
                          errors.description
                            ? "border-red-500 border outline-none focus:outline-none"
                            : ""
                        }`}
                        required
                        name="description"
                        value={formData.description}
                        onChange={handleChange}
                        placeholder="Tell us about your Boats (max. 300 characters)"
                        // defaultValue={""}
                      />
                    </div>
                  </div>
                  {errors.description && (
                    <span className="text-red-500 text-sm font-medium absolute top-0]">
                      **{errors.description}
                    </span>
                  )}
                </div>
                <div className="col-span-2">
                  <div className="w-full  ">
                    <textarea
                      id="description"
                      name="description"
                      rows={5}
                      className="mt-1 block w-full outline-none  p-3 border-2 border-black/10  rounded-md shadow-sm  sm:text-sm"
                      placeholder="Description"
                      value={description}
                      onChange={handleDescriptionChange}
                    />
                  </div>
                </div>
                {/* 11 length */}
                <div className="relative dropdown-container">
                  <div className="custom-container-dev">
                    <input
                      type="text"
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                        errors.length && !formData.length
                          ? "input-field-error "
                          : ""
                      }`}
                      placeholder="Length"
                      name=" length"
                      value={formData.length}
                      readOnly // Ensure input is read-only
                      onClick={() => handleToggleDropdown("length")}
                    />
                  </div>
                  {errors.length && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.length}
                    </span>
                  )}
                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                      onClick={() => handleToggleDropdown(" length")}
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                      onClick={() => handleToggleDropdown("length")}
                    />
                  </div>
                  {dropdowns.length && (
                    <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      {length.map((option, index) => (
                        <div
                          key={index}
                          className="dropdown-option"
                          onClick={() => handleSelectOption("length", option)}
                        >
                          {option}
                        </div>
                      ))}
                    </div>
                  )}
                </div>

                {/* 12  brands*/}
                <div className="relative w-full dropdown-container">
                  <div className="relative-placeholder w-full">
                    <input
                      type="text"
                      maxLength={50}
                      className="shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal"
                      name="brands"
                      value={formData.brands}
                      onChange={handleChange}
                      required
                    />

                    {formData.brands === "" && (
                      <div
                        className={`custom-placeholder text-sm absolute left-5 top-1/2 transform -translate-y-1/2 pointer-events-none transition-all duration-200 ease-in-out
                      ${errors.brands ? "input-field-error" : ""}
                      `}
                      >
                        <span className="text-gray-400">Brands </span>
                        <span className="optional text-xs text-yellow-600">
                          (Optional)
                        </span>
                      </div>
                    )}
                    {errors.brands && (
                      <span className="text-red-500 text-sm font-medium absolute top-[98%]">
                        **{errors.brands}
                      </span>
                    )}
                  </div>
                </div>
                {/* 13  locate boat*/}
                <div className="relative w-full dropdown-container">
                  <div className="relative-placeholder w-full">
                    <input
                      type="text"
                      maxLength={50}
                      className="shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal"
                      name="locateBoat"
                      value={formData.locateBoat}
                      onChange={handleChange}
                      required
                    />

                    {formData.locateBoat === "" && (
                      <div
                        className={`custom-placeholder text-sm absolute left-5 top-1/2 transform -translate-y-1/2 pointer-events-none transition-all duration-200 ease-in-out
                      ${errors.locateBoat ? "input-field-error" : ""}
                      `}
                      >
                        <span className="text-gray-400">Locate Your Boat </span>
                        <span className="optional text-xs text-yellow-600">
                          (Optional)
                        </span>
                      </div>
                    )}
                    {errors.locateBoat && (
                      <span className="text-red-500 text-sm font-medium absolute top-[98%]">
                        **{errors.locateBoat}
                      </span>
                    )}
                  </div>
                </div>
                {/* 14  usage*/}
                <div className="relative dropdown-container">
                  <div className="custom-container-dev">
                    <input
                      type="text"
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                        errors.usage && !formData.usage
                          ? "input-field-error "
                          : ""
                      }`}
                      placeholder="Usage"
                      name="usage"
                      value={formData.usage}
                      readOnly // Ensure input is read-only
                      onClick={() => handleToggleDropdown("usage")}
                    />
                  </div>
                  {errors.usage && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.usage}
                    </span>
                  )}
                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                      onClick={() => handleToggleDropdown(" usage")}
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                      onClick={() => handleToggleDropdown("usage")}
                    />
                  </div>
                  {dropdowns.usage && (
                    <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      {usage.map((option, index) => (
                        <div
                          key={index}
                          className="dropdown-option"
                          onClick={() => handleSelectOption("usage", option)}
                        >
                          {option}
                        </div>
                      ))}
                    </div>
                  )}
                </div>
                {/* 15  age*/}
                <div className="relative dropdown-container">
                  <div className="custom-container-dev">
                    <input
                      type="text"
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                        errors.age && !formData.age ? "input-field-error " : ""
                      }`}
                      placeholder="Age"
                      name="age"
                      value={formData.age}
                      readOnly // Ensure input is read-only
                      onClick={() => handleToggleDropdown("age")}
                    />
                  </div>
                  {errors.age && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.age}
                    </span>
                  )}
                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                      onClick={() => handleToggleDropdown(" age")}
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                      onClick={() => handleToggleDropdown("age")}
                    />
                  </div>
                  {dropdowns.age && (
                    <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      {age.map((option, index) => (
                        <div
                          key={index}
                          className="dropdown-option"
                          onClick={() => handleSelectOption("age", option)}
                        >
                          {option}
                        </div>
                      ))}
                    </div>
                  )}
                </div>
                {/* 16  sports*/}
                <div className="relative w-full dropdown-container">
                  <div className="relative-placeholder w-full">
                    <input
                      type="text"
                      maxLength={50}
                      className="shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal"
                      name="sportsOutdoorPrice"
                      value={formData.sportsOutdoorPrice}
                      onChange={handleChange}
                      required
                    />

                    {formData.sportsOutdoorPrice === "" && (
                      <div
                        className={`custom-placeholder text-sm absolute left-5 top-1/2 transform -translate-y-1/2 pointer-events-none transition-all duration-200 ease-in-out
                      ${errors.sportsOutdoorPrice ? "input-field-error" : ""}
                      `}
                      >
                        <span className="text-gray-400">
                          Sports & Outdoor Price{" "}
                        </span>
                        <span className="optional text-xs text-yellow-600">
                          (Optional)
                        </span>
                      </div>
                    )}
                    {errors.sportsOutdoorPrice && (
                      <span className="text-red-500 text-sm font-medium absolute top-[98%]">
                        **{errors.sportsOutdoorPrice}
                      </span>
                    )}
                  </div>
                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                    />
                  </div>
                </div>
                {/* 17  seats*/}
                <div className="relative w-full dropdown-container">
                  <div className="relative-placeholder w-full">
                    <div className="custom-container-dev">
                      <input
                        type="text"
                        name="seats"
                        value={formData.seats}
                        placeholder="Seats"
                        onChange={handleChange}
                        className={`input-with-placeholder form-input shadow-neons w-full h-[50px] pl-5 pr-14 placeholder:text-dark-grey placeholder:text-[15px] placeholder:font-normal card-number-input ${
                          errors.seats
                            ? "border-red-500 border outline-none focus:outline-none"
                            : ""
                        }`}
                        required
                      />
                    </div>
                    {errors.seats && (
                      <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                        **{errors.seats}
                      </span>
                    )}
                  </div>
                </div>
                {/* 18  warrenty*/}
                <div className="relative dropdown-container">
                  <div className="custom-container-dev">
                    <input
                      type="text"
                      className={`shadow-neons w-full h-[50px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input ${
                        errors.warrenty && !formData.warrenty
                          ? "input-field-error "
                          : ""
                      }`}
                      placeholder="Warrenty"
                      name="warrenty"
                      value={formData.warrenty}
                      readOnly // Ensure input is read-only
                      onClick={() => handleToggleDropdown("warrenty")}
                    />
                  </div>
                  {errors.warrenty && (
                    <span className="text-red-500 text-sm font-medium absolute top-[50px]">
                      **{errors.warrenty}
                    </span>
                  )}
                  <div className="absolute inset-y-0 right-0 top-[16px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                    <Image
                      width={12}
                      height={12}
                      src="/listing/Vector.svg"
                      alt="Dropdown"
                      className="toggle-icon"
                      onClick={() => handleToggleDropdown(" warrenty")}
                    />
                    <Image
                      width={12}
                      height={12}
                      src="/listing/vector1.svg"
                      alt="Dropdown"
                      className="toggle-icon rotate-180"
                      onClick={() => handleToggleDropdown("warrenty")}
                    />
                  </div>
                  {dropdowns.warrenty && (
                    <div className="absolute z-10 p-4 inset-y-0 right-0 w-full h-fit bg-white border border-gray-2 rounded-md shadow-md top-[60px] flex flex-col gap-2 items-center pr-[15px] cursor-pointer dropdown-toggle">
                      {warrenty.map((option, index) => (
                        <div
                          key={index}
                          className="dropdown-option"
                          onClick={() => handleSelectOption("warrenty", option)}
                        >
                          {option}
                        </div>
                      ))}
                    </div>
                  )}
                </div>
                {/* end  */}
              </div>
            </form>
            {/* input two  */}
            <div className="pt-[30px]">
              <div className="px-[19px]">
                {/* exterior colors--------------------------------> */}
                <h2 className="text-dark-black text-xl font-medium">
                  Exterior Color
                </h2>

                {/* dynamic arham */}
                <form className="mt-[10px] grid xl:grid-cols-8 lg:grid-cols-6 md:grid-cols-4 sm:grid-cols-3 xxs:grid-cols-2 justify-between gap-y-[10px]">
                  {colors.map((color) => (
                    <div key={color}>
                      <input
                        type="checkbox"
                        className="custom-checkbox"
                        value={color}
                        checked={selectedExteriorColors.includes(color)}
                        onChange={handleExteriorCheckboxChange}
                      />
                      <label className="custom-label">{color}</label>
                    </div>
                  ))}
                  <div className="flex space-x-[7px] items-center">
                    <div>
                      <input
                        type="checkbox"
                        className="custom-checkbox"
                        value="Other"
                        checked={!!otherExteriorColor}
                        onChange={() => setOtherExteriorColor("")}
                      />
                    </div>
                    <input
                      type="text"
                      className="shadow-neonsm w-[167px] h-[24px] placeholder:text-light-black
            placeholder:text-xs placeholder:font-normal pl-[10px]"
                      placeholder="Type Other Color"
                      value={otherExteriorColor}
                      onChange={handleOtherExteriorColorChange}
                    />
                  </div>
                </form>

                {/* 2 interior----------   */}
                <h2 className="text-dark-black text-xl font-medium pt-5">
                  Interior Color
                </h2>

                <form className="mt-[10px] grid xl:grid-cols-8 lg:grid-cols-6 md:grid-cols-4 sm:grid-cols-3 xxs:grid-cols-2 justify-between gap-y-[10px]">
                  {colors.map((color) => (
                    <div key={color}>
                      <input
                        type="checkbox"
                        className="custom-checkbox"
                        value={color}
                        checked={selectedInteriorColors.includes(color)}
                        onChange={handleInteriorCheckboxChange}
                      />
                      <label className="custom-label">{color}</label>
                    </div>
                  ))}
                  <div className="flex space-x-[7px] items-center">
                    <div>
                      <input
                        type="checkbox"
                        className="custom-checkbox"
                        value="Other"
                        checked={!!otherInteriorColor}
                        onChange={() => setOtherInteriorColor("")}
                      />
                    </div>
                    <input
                      type="text"
                      className="shadow-neonsm w-[167px] h-[24px] placeholder:text-light-black
            placeholder:text-xs placeholder:font-normal pl-[10px]"
                      placeholder="Type Other Color"
                      value={otherInteriorColor}
                      onChange={handleOtherInteriorColorChange}
                    />
                  </div>
                </form>
                {/* 3 extraaaaaa */}
                <div>
                  <h2 className="text-dark-black text-xl font-medium pt-5">
                    Extras
                  </h2>
                  <form className="mt-[10px] grid xl:grid-cols-5 lg:grid-cols-3 md:grid-cols-3 sm:grid-cols-2 xxs:grid-cols-1 justify-between gap-y-[10px]">
                    {extrasList.map((extra) => (
                      <div key={extra}>
                        <input
                          type="checkbox"
                          className="custom-checkbox"
                          value={extra}
                          checked={selectedExtras.includes(extra)}
                          onChange={handleCheckboxChange}
                        />
                        <label className="custom-label">{extra}</label>
                      </div>
                    ))}
                  </form>
                </div>
              </div>
              {/* 4 end image boat */}
              <div className="grid place-items-center mt-[30px]">
                <Image
                  width={1500}
                  quality={90}
                  className="w-[98%]"
                  height={700}
                  src="/listing/boat.png"
                  alt="boat"
                />
              </div>
              {/* map  */}
              <div className="mt-[20px]">
                <iframe
                  className="max-w-[1064px] w-full mx-auto h-[351px] rounded-[5px] shadow-neons"
                  src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d231280.4131872353!2d55.06267954491565!3d25.0762424478002!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x3e5f43496ad9c645%3A0xbde66e5084295162!2sDubai%20-%20United%20Arab%20Emirates!5e0!3m2!1sen!2s!4v1716351024030!5m2!1sen!2s"
                  allowFullScreen
                  loading="lazy"
                  referrerPolicy="no-referrer-when-downgrade"
                />
              </div>
              {/* submit button */}
              <div className="grid place-items-center mt-[30px] pb-[65px]">
                <button
                  className={`text-whitee flex justify-center items-center text-xl font-medium w-[205px] h-[50px] rounded-[3px] bg-light-gold shadow-neons`}
                  onClick={handleSubmit}
                  disabled={loading}
                >
                  {loading ? (
                    <IoReload size={24} className="animate-spin" />
                  ) : (
                    "Submit"
                  )}
                </button>
              </div>
            </div>
          </main>
        </div>
      </section>
    </div>
  );
}

export default Page;
